Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(951)

Unified Diff: Source/core/rendering/RenderBlock.cpp

Issue 948343003: Move rendering/RenderGrid to layout/LayoutGrid (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/paint/GridPainter.cpp ('k') | Source/core/rendering/RenderGrid.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/rendering/RenderBlock.cpp
diff --git a/Source/core/rendering/RenderBlock.cpp b/Source/core/rendering/RenderBlock.cpp
index 91dcfe3096b9f5d1429cd210db41f7ac923c8dcb..24d5135ac58a895861ae66a80fda77d918334765 100644
--- a/Source/core/rendering/RenderBlock.cpp
+++ b/Source/core/rendering/RenderBlock.cpp
@@ -42,6 +42,7 @@
#include "core/layout/HitTestResult.h"
#include "core/layout/Layer.h"
#include "core/layout/LayoutFlowThread.h"
+#include "core/layout/LayoutGrid.h"
#include "core/layout/LayoutObject.h"
#include "core/layout/LayoutRegion.h"
#include "core/layout/LayoutTableCell.h"
@@ -61,7 +62,6 @@
#include "core/rendering/RenderCombineText.h"
#include "core/rendering/RenderDeprecatedFlexibleBox.h"
#include "core/rendering/RenderFlexibleBox.h"
-#include "core/rendering/RenderGrid.h"
#include "core/rendering/RenderInline.h"
#include "core/rendering/RenderTextFragment.h"
#include "core/rendering/RenderView.h"
@@ -1066,9 +1066,9 @@ void RenderBlock::removeLeftoverAnonymousBlock(RenderBlock* child)
// Remove all the information in the flow thread associated with the leftover anonymous block.
child->removeFromLayoutFlowThread();
- // RenderGrid keeps track of its children, we must notify it about changes in the tree.
- if (child->parent()->isRenderGrid())
- toRenderGrid(child->parent())->dirtyGrid();
+ // LayoutGrid keeps track of its children, we must notify it about changes in the tree.
+ if (child->parent()->isLayoutGrid())
+ toLayoutGrid(child->parent())->dirtyGrid();
child->setParent(0);
child->setPreviousSibling(0);
« no previous file with comments | « Source/core/paint/GridPainter.cpp ('k') | Source/core/rendering/RenderGrid.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698